==> ejc-zdscost-api-3.0.0-20250806.074402-110-sources.jar: com/ejianc/business/zdscost/vo/BudgetProjectDetailPackageVO.java <==
package com.ejianc.business.zdscost.vo;

import com.ejianc.business.zdscost.util.IZDSTreeNodeB;
import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 切包清单PackageVO
 *
 * @author generator
 *
 */
@ApiModel("切包清单PackageVO")
public class BudgetProjectDetailPackageVO implements Serializable, IZDSTreeNodeB {
    private static final long serialVersionUID = 1L;

    private Long budgetId;

    private Long id;

    private String code;

    private String name;

    private BigDecimal money;

    private BigDecimal upperMoney;


    private Long parentId;

    private List<IZDSTreeNodeB> children;


    private Long bigPackId;
    private String packageFlag;
    private Long packId;

    private String searchText;

    public String getSearchText() {
        return searchText;
    }

    public void setSearchText(String searchText) {
        this.searchText = searchText;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getBigPackId() {
        return bigPackId;
    }

    public void setBigPackId(Long bigPackId) {
        this.bigPackId = bigPackId;
    }

    public String getPackageFlag() {
        return packageFlag;
    }

    public void setPackageFlag(String packageFlag) {
        this.packageFlag = packageFlag;
    }

    public Long getPackId() {
        return packId;
    }

    public void setPackId(Long packId) {
        this.packId = packId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getUpperMoney() {
        return upperMoney;
    }

    public void setUpperMoney(BigDecimal upperMoney) {
        this.upperMoney = upperMoney;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    @Override
    public void setChildren(List<IZDSTreeNodeB> children) {
        this.children = children;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<IZDSTreeNodeB> getChildren() {
        return children;
    }


    public Long getParentId() {
        return parentId;
    }


}

==> ejc-zdscost-api-3.0.0-20250815.013547-137-sources.jar: com/ejianc/business/zdscost/vo/BudgetProjectDetailPackageVO.java <==
package com.ejianc.business.zdscost.vo;

import com.ejianc.business.zdscost.util.IZDSTreeNodeB;
import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 切包清单PackageVO
 *
 * @author generator
 *
 */
@ApiModel("切包清单PackageVO")
public class BudgetProjectDetailPackageVO implements Serializable, IZDSTreeNodeB {
    private static final long serialVersionUID = 1L;

    private Long budgetId;

    private Long id;

    private String code;

    private String name;

    private BigDecimal money;

    private BigDecimal upperMoney;


    private Long parentId;

    private List<IZDSTreeNodeB> children;


    private Long bigPackId;
    private String packageFlag;
    private Long packId;

    private String searchText;

    private String dianLiangState;


    public String getDianLiangState() {
        return dianLiangState;
    }

    public void setDianLiangState(String dianLiangState) {
        this.dianLiangState = dianLiangState;
    }

    public String getSearchText() {
        return searchText;
    }

    public void setSearchText(String searchText) {
        this.searchText = searchText;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getBigPackId() {
        return bigPackId;
    }

    public void setBigPackId(Long bigPackId) {
        this.bigPackId = bigPackId;
    }

    public String getPackageFlag() {
        return packageFlag;
    }

    public void setPackageFlag(String packageFlag) {
        this.packageFlag = packageFlag;
    }

    public Long getPackId() {
        return packId;
    }

    public void setPackId(Long packId) {
        this.packId = packId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getUpperMoney() {
        return upperMoney;
    }

    public void setUpperMoney(BigDecimal upperMoney) {
        this.upperMoney = upperMoney;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    @Override
    public void setChildren(List<IZDSTreeNodeB> children) {
        this.children = children;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<IZDSTreeNodeB> getChildren() {
        return children;
    }


    public Long getParentId() {
        return parentId;
    }


}
